@@ -15,7 +15,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @EXPORT = ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 1;
 __END__
@@ -41,6 +41,16 @@ Sparse - Perl module for Sparse Vectors
   # returns the indices of non-zero values in sorted order
   @indices = $spvec->keys;
 
+  # returns 1 if the vector is empty and has no keys
+  if($spvec->isnull)
+  {
+        print "vector is null.\n";
+  }
+  else
+  {
+        print "vector is not null.\n";
+  }
+
   # print sparse vector to stdout
   $spvec->print;
 
