@@ -20,7 +20,7 @@ use overload
 
 @EXPORT = ();
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 # sparse vector contructor 
 # creates an empty sparse vector
@@ -77,6 +77,18 @@ sub keys
 	return @sorted;
 }
 
+# returns 1 if the vector is empty
+sub isnull
+{
+	my $self = shift;
+	my @indices = $self->keys;
+	if(scalar(@indices)==0)
+	{
+		return 1;
+	}
+	return 0;
+}
+
 # prints sparse vector
 sub print
 {
@@ -155,7 +167,10 @@ sub normalize
 {
 	my $self = shift;
 	my $vnorm = $self->norm;
-	$self->div($vnorm);
+	if($vnorm != 0)
+	{
+		$self->div($vnorm);
+	}
 }
 
 sub dot
@@ -248,6 +263,16 @@ Sparse::Vector - Implements Sparse Vector Operations
   # returns the indices of non-zero values in sorted order
   @indices = $spvec->keys;
 
+  # returns 1 if the vector is empty and has no keys
+  if($spvec->isnull)
+  {
+	print "vector is null.\n";
+  }
+  else
+  {
+	print "vector is not null.\n";
+  }
+
   # print sparse vector to stdout
   $spvec->print;
 
